@@ -2,11 +2,12 @@ package FusionInventory::Agent::SNMP::Live;
 
 use strict;
 use warnings;
-use base 'FusionInventory::Agent::SNMP';
+use parent 'FusionInventory::Agent::SNMP';
 
 use Encode qw(encode);
 use English qw(-no_match_vars);
 use Net::SNMP;
+use Net::SNMP qw/SNMP_PORT/;
 
 sub new {
     my ($class, %params) = @_;
@@ -29,6 +30,8 @@ sub new {
         -retries  => 0,
         -version  => $version,
         -hostname => $params{hostname},
+        -port     => $params{port}      || SNMP_PORT,
+        -domain   => $params{domain}    || 'udp/ipv4',
     );
     $options{'-timeout'} = $params{timeout} if $params{timeout};
 
@@ -172,6 +175,16 @@ sub walk {
     return $values;
 }
 
+sub peer_address {
+    my ($self) = @_;
+
+    # transport() API is not documented in Net::SNMP
+    my $transport = $self->{session}->transport()
+        or return;
+
+    return $transport->peer_address();
+}
+
 1;
 __END__
 
@@ -212,6 +225,24 @@ The transport layer timeout
 
 =item hostname (mandatory)
 
+=item port
+
+=item domain
+
+Can be one of:
+
+=over
+
+=item 'udp/ipv4' (default)
+
+=item 'udp/ipv6'
+
+=item 'tcp/ipv4'
+
+=item 'tcp/ipv6'
+
+=back
+
 =item community
 
 =item username
