@@ -2,7 +2,8 @@ package FusionInventory::Agent::Target::Server;
 
 use strict;
 use warnings;
-use base 'FusionInventory::Agent::Target';
+
+use parent 'FusionInventory::Agent::Target';
 
 use English qw(-no_match_vars);
 use URI;
@@ -12,7 +13,7 @@ my $count = 0;
 sub new {
     my ($class, %params) = @_;
 
-    die "no url parameter" unless $params{url};
+    die "no url parameter for server target\n" unless $params{url};
 
     my $self = $class->SUPER::new(%params);
 
@@ -59,18 +60,29 @@ sub getUrl {
     return $self->{url};
 }
 
-sub _getName {
+sub getName {
     my ($self) = @_;
 
     return $self->{url};
 }
 
-sub _getType {
+sub getType {
     my ($self) = @_;
 
     return 'server';
 }
 
+sub plannedTasks {
+    my $self = shift @_;
+
+    # Server can trigger any task but Maintenance
+    if (@_) {
+        $self->{tasks} = [ grep { $_ !~ /^Maintenance$/i } @_ ];
+    }
+
+    return @{$self->{tasks} || []};
+}
+
 1;
 
 __END__
@@ -102,3 +114,17 @@ the server URL (mandatory)
 =head2 getUrl()
 
 Return the server URL for this target.
+
+=head2 getName()
+
+Return the target name
+
+=head2 getType()
+
+Return the target type
+
+=head2 plannedTasks([@tasks])
+
+Initializes target tasks with supported ones if a list of tasks is provided
+
+Return an array of planned tasks.
